API Reference
=============

.. autoclass:: notcl.TclTool
   :members: cmdline, script_name, eval

   .. automethod:: __init__

.. autoclass:: notcl.tcltool.TclToolInterface
   :members:

   .. automethod:: __getattr__
   .. automethod:: __call__

.. autoclass:: notcl.tclobj.TclRemoteObjRef
   :members:

.. autoclass:: notcl.TclError
   :members:

.. autoclass:: notcl.ChildProcessEarlyExit
   :members:
